@@ -14,30 +14,6 @@ async fn it_connects() -> anyhow::Result<()> {
     Ok(())
 }
 
-#[async_std::test]
-async fn it_connects_to_database_user() -> anyhow::Result<()> {
-    let mut conn = connect().await?;
-
-    let row = sqlx::query("select current_database()")
-        .fetch_one(&mut conn)
-        .await?;
-
-    let current_db: String = row.get(0);
-
-    let row = sqlx::query("select current_user")
-        .fetch_one(&mut conn)
-        .await?;
-
-    let current_user: String = row.get(0);
-
-    assert_eq!(current_db, "postgres");
-    assert_eq!(current_user, "postgres");
-
-    conn.close().await?;
-
-    Ok(())
-}
-
 #[async_std::test]
 async fn it_executes() -> anyhow::Result<()> {
     let mut conn = connect().await?;
